@@ -1,9 +1,9 @@
 from pathlib import Path
 
-__all__ = ["sequencify_files"]
+__all__ = ["sequence_files"]
 
 
-def sequencify_files(frames_dir: Path):
+def sequence_files(frames_dir: Path) -> None:
     """
 
     :param frames_dir:
@@ -17,6 +17,6 @@ def sequencify_files(frames_dir: Path):
 
 
 if __name__ == "__main__":
-    sequencify_files(
+    sequence_files(
         Path(r"G:/") / "Mit drev" / "upscaled" / "restored_imgs",
     )
