@@ -16,3 +16,8 @@ from .generators import *
 from .http import *
 from .sockets import *
 from .torch_like_channel_transformation import *
+from .counter_filter import *
+from .matrix import *
+from .iterators import *
+from .display import *
+from .platform_context import *
