@@ -9,8 +9,10 @@ __doc__ = r"""
 
 __all__ = ["in_ipynb"]
 
+import sys
 
-def in_ipynb() -> bool:
+
+def in_ipynb(verbose: bool = False) -> bool:
     """
 
     :return:
@@ -18,8 +20,11 @@ def in_ipynb() -> bool:
     """
     try:
         from IPython import get_ipython
+        import jupyter
 
         shell = get_ipython().__class__.__name__
+        if verbose:
+            print(f"found shell: {shell}")
         if shell == "ZMQInteractiveShell":
             return True  # Jupyter notebook or qtconsole
         elif shell == "TerminalInteractiveShell":
@@ -27,6 +32,19 @@ def in_ipynb() -> bool:
         else:
             return False  # Other type (?)
     except NameError:
+        if verbose:
+            print(f"Probably standard Python interpreter")
         return False  # Probably standard Python interpreter
     except ModuleNotFoundError:
-        return False
+        if "ipykernel" in sys.modules:
+            if verbose:
+                print(f"Found ipykernel in sys.modules")
+            return True
+
+        if verbose:
+            print(f"Did not find Ipython")
+        return False  # Did not find Ipython
+
+
+if __name__ == "__main__":
+    in_ipynb()
