@@ -110,7 +110,7 @@ class SplitDictDatasetFolder(VisionDataset):
         return self.sample(target, index)
 
     def sample(self, target, index) -> Tuple:
-        """ """
+        """description"""
         sample = self.loader(
             self._data_categories[target][index % self.category_sizes[target]]
         )
@@ -196,7 +196,7 @@ class DictDatasetFolder(VisionDataset):
         return self.sample(target, index)
 
     def sample(self, target, index) -> Tuple:
-        """ """
+        """description"""
         sample = self.loader(self._data[target][index % self.category_sizes[target]])
         if self.transform is not None:
             sample = self.transform(sample)
